package kieker.webgui.beans.application;

import java.util.Map;
import java.util.TreeMap;
import javax.annotation.PostConstruct;
import javax.faces.bean.ApplicationScoped;
import javax.faces.bean.ManagedBean;

/**
 * This bean is an application-wide bean, responsible for storing the possible themes (look and feels) available within the program. It is not possible to import new
 * themes during runtime.
 * 
 * @author Nils Christian Ehmke
 */
@ManagedBean
@ApplicationScoped
public class ThemeSwitcherBean {

	private Map<String, String> themes;

	/**
	 * Returns the available themes.
	 * 
	 * @return A map containing the user readable names of the themes as a key and the actual theme-names as the corresponding value.
	 */
	public Map<String, String> getThemes() {
		return themes;
	}

	/**
	 * Initializes the bean. If one wants to add new themes to the program, this is the right place.
	 */
	@PostConstruct
	public void init() {
		themes = new TreeMap<String, String>();

		themes.put("Aristo", "aristo");
		themes.put("Black-Tie", "black-tie");
		themes.put("Blitzer", "blitzer");
		themes.put("Bluesky", "bluesky");
		themes.put("Casablanca", "casablanca");
		themes.put("Cupertino", "cupertino");
		themes.put("Dark-Hive", "dark-hive");
		themes.put("Dot-Luv", "dot-luv");
		themes.put("Eggplant", "eggplant");
		themes.put("Excite-Bike", "excite-bike");
		themes.put("Flick", "flick");
		themes.put("Glass-X", "glass-x");
		themes.put("Hot-Sneaks", "hot-sneaks");
		themes.put("Humanity", "humanity");
		themes.put("Le-Frog", "le-frog");
		themes.put("Midnight", "midnight");
		themes.put("Mint-Choc", "mint-choc");
		themes.put("Overcast", "overcast");
		themes.put("Pepper-Grinder", "pepper-grinder");
		themes.put("Redmond", "redmond");
		themes.put("Rocket", "rocket");
		themes.put("Sam", "sam");
		themes.put("Smoothness", "smoothness");
		themes.put("South-Street", "south-street");
		themes.put("Start", "start");
		themes.put("Sunny", "sunny");
		themes.put("Swanky-Purse", "swanky-purse");
		themes.put("Trontastic", "trontastic");
		themes.put("UI-Darkness", "ui-darkness");
		themes.put("UI-Lightness", "ui-lightness");
		themes.put("Vader", "vader");
	}
}
